Package: poissonreg
Title: Model Wrappers for Poisson Regression
Version: 1.0.2
Authors@R: c(
    person("Max", "Kuhn", , "max@posit.co", role = "aut",
           comment = c(ORCID = "0000-0003-2402-136X")),
    person("Hannah", "Frick", , "hannah@posit.co", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-6049-5258")),
    person("Posit Software, PBC", role = c("cph", "fnd"),
           comment = c(ROR = "03wc8by49"))
  )
Description: Bindings for Poisson regression models for use with the
    'parsnip' package. Models include simple generalized linear models,
    Bayesian models, and zero-inflated Poisson models (Zeileis, Kleiber,
    and Jackman (2008) <doi:10.18637/jss.v027.i08>).
License: MIT + file LICENSE
URL: https://github.com/tidymodels/poissonreg,
        https://poissonreg.tidymodels.org/
BugReports: https://github.com/tidymodels/poissonreg/issues
Depends: parsnip (>= 0.2.0), R (>= 4.1)
Imports: dplyr, generics, purrr, rlang, stats, tibble, tidyr
Suggests: covr, glmnet, pscl, rstanarm, spelling, testthat (>= 3.0.0)
Config/Needs/website: tidymodels, tidyverse/tidytemplate
Config/testthat/edition: 3
Config/usethis/last-upkeep: 2025-04-24
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-20 12:20:55 UTC; hannah
Author: Max Kuhn [aut] (ORCID: <https://orcid.org/0000-0003-2402-136X>),
  Hannah Frick [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-6049-5258>),
  Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>)
Maintainer: Hannah Frick <hannah@posit.co>
Repository: CRAN
Date/Publication: 2026-04-20 13:20:07 UTC
Built: R 4.6.0; ; 2026-04-26 20:12:26 UTC; unix
