#' Alcohol, Cigarette, and Marijuana Use for High School Seniors
#'
#' @details Data are from Table 7.3 of Agresti (2007). The first three columns
#' make up data from a 3-way contingency table.
#'
#' @name seniors
#' @aliases seniors
#' @docType data
#' @return \item{seniors}{a tibble}
#'
#' @source Agresti, A (2007). _An Introduction to Categorical Data Analysis_.
#'
#' @keywords datasets
#' @examples
#' data(seniors)
#' str(seniors)
NULL
