% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tidy.R
\name{tidy_zip}
\alias{tidy_zip}
\alias{tidy.zeroinfl}
\alias{tidy.hurdle}
\title{Turn zero-inflated model results into a tidy tibble}
\usage{
\method{tidy}{zeroinfl}(x, type = "count", ...)

\method{tidy}{hurdle}(x, type = "count", ...)
}
\arguments{
\item{x}{A \code{hurdle} or \code{zeroinfl} model object.}

\item{type}{A character string for which model coefficients to return:
"all", "count", or "zero".}

\item{...}{Not currently used.}
}
\value{
A tibble
}
\description{
Turn zero-inflated model results into a tidy tibble
}
